@@ -2,22 +2,22 @@
 Tests asilib/analysis.equal_area.py
 """
 
-from datetime import date, datetime
-from os import path
+from datetime import datetime
 import unittest
 import pathlib
 
+import pytest
 import numpy as np
 
 import asilib
 from asilib.io.load import load_skymap
-from asilib.analysis.equal_area import equal_area, _dlon, _dlat
+from asilib.analysis.equal_area import _dlon, _dlat
 
 # Number of km in a degree of latitude. Also a degree of longitude at the equator
 deg_distance_km = 111.321
 
 
-class Test_keogram(unittest.TestCase):
+class Test_equal_area(unittest.TestCase):
     def test_dlat(self):
         """
         Tests the _dlat() helper function. Given one altitude, these should be the same.
@@ -60,14 +60,13 @@ class Test_keogram(unittest.TestCase):
         return
 
     def test_equal_area(self, create_reference=False):
-        mission = 'THEMIS'
-        station = 'RANK'
+        asi_array_code = 'THEMIS'
+        location_code = 'RANK'
         time = datetime(2020, 1, 1)
-        box_km = (10, 10)  # in (Lat, Lon) directions.
-        skymap_dict = load_skymap(mission, station, time)
+        skymap_dict = load_skymap(asi_array_code, location_code, time)
 
         # Set up a north-south satellite track oriented to the east of the THEMIS/RANK
-        # station.
+        # imager.
         n = 10
         lats = np.linspace(
             skymap_dict["SITE_MAP_LATITUDE"] + 5, skymap_dict["SITE_MAP_LATITUDE"] - 5, n
@@ -76,7 +75,7 @@ class Test_keogram(unittest.TestCase):
         alts = 110 * np.ones(n)
         lla = np.array([lats, lons, alts]).T
 
-        area_box_mask = asilib.equal_area(mission, station, time, lla, box_km=(20, 20))
+        area_box_mask = asilib.equal_area(asi_array_code, location_code, time, lla, box_km=(20, 20))
 
         reference_path = pathlib.Path(
             asilib.config['ASILIB_DIR'], 'tests', 'data', 'area_box_mask.npy'
@@ -88,6 +87,26 @@ class Test_keogram(unittest.TestCase):
             assert np.array_equal(area_box_mask, area_box_mask_reference, equal_nan=True)
         return
 
+    def test_equal_area_below_horizon(self):
+        asi_array_code = 'THEMIS'
+        location_code = 'RANK'
+        time = datetime(2020, 1, 1)
+        skymap_dict = load_skymap(asi_array_code, location_code, time)
+
+        # Set up a north-south satellite track oriented to the east of the THEMIS/RANK
+        # imager.
+        n = 10
+        lats = np.linspace(0, 5, n)  # Just above the equator, way below the horizon.
+        lons = (skymap_dict["SITE_MAP_LONGITUDE"] - 0.5) * np.ones(n)
+        alts = 110 * np.ones(n)
+        lla = np.array([lats, lons, alts]).T
+        with pytest.warns(UserWarning):
+            area_box_mask = asilib.equal_area(
+                asi_array_code, location_code, time, lla, box_km=(20, 20)
+            )
+        assert np.all(np.isnan(area_box_mask))
+        return
+
 
 if __name__ == '__main__':
     unittest.main()
